@@ -7,6 +7,22 @@ class CommonPolynomialTrend(AbstractCommon):
 
     parameters_dictionary = {
         'x_zero': # reference value of the polynomial
+            {
+                'bounds': [-1e09, 1e09],
+                'priors': ['Uniform', []],
+                'spaces': 'Linear',
+                'fixed' : 0.00,
+                'unit': 'as input',
+            },
+        'x_offset': # reference value of the polynomial
+            {
+                'bounds': [-1e09, 1e09],
+                'priors': ['Uniform', []],
+                'spaces': 'Linear',
+                'fixed' : 0.00,
+                'unit': 'as input',
+            },
+        'poly_factor': # reference value of the polynomial
             {
                 'bounds': [-1e09, 1e09],
                 'priors': ['Uniform', []],
@@ -26,6 +42,7 @@ class CommonPolynomialTrend(AbstractCommon):
                 'unit': 'poly order '+repr(i_pol),
         }
 
+
     default_fixed = {}
 
     recenter_pams = {}
